@@ -27,6 +27,8 @@
 #include <Qt3DAnimation/qkeyframeanimation.h>
 #include <Qt3DAnimation/qmorphinganimation.h>
 
+QT_BEGIN_NAMESPACE
+
 namespace Qt3DAnimation {
     class QAbstractAnimationClip;
     class QAbstractChannelMapping;
@@ -38,6 +40,7 @@ namespace Qt3DAnimation {
     class QAnimationController;
     class QAnimationGroup;
     class QBlendedClipAnimator;
+    class QCallbackMapping;
     class QChannel;
     class QChannelComponent;
     class QChannelMapper;
@@ -50,6 +53,7 @@ namespace Qt3DAnimation {
     class QSkeletonMapping;
     class QVertexBlendAnimation;
 }
+QT_END_NAMESPACE
 
 // Type indices
 enum [[deprecated]] : int {
@@ -72,24 +76,25 @@ enum [[deprecated]] : int {
     SBK_QT3DANIMATION_QANIMATIONCONTROLLER_IDX               = 32,
     SBK_QT3DANIMATION_QANIMATIONGROUP_IDX                    = 34,
     SBK_QT3DANIMATION_QBLENDEDCLIPANIMATOR_IDX               = 36,
-    SBK_QT3DANIMATION_QCHANNEL_IDX                           = 38,
-    SBK_QT3DANIMATION_QCHANNELCOMPONENT_IDX                  = 40,
-    SBK_QT3DANIMATION_QCHANNELMAPPER_IDX                     = 42,
-    SBK_QT3DANIMATION_QCHANNELMAPPING_IDX                    = 44,
-    SBK_QT3DANIMATION_QCLIPANIMATOR_IDX                      = 46,
-    SBK_QT3DANIMATION_QCLIPBLENDVALUE_IDX                    = 48,
-    SBK_QT3DANIMATION_QCLOCK_IDX                             = 50,
-    SBK_QT3DANIMATION_QKEYFRAME_INTERPOLATIONTYPE_IDX        = 54,
-    SBK_QT3DANIMATION_QKEYFRAME_IDX                          = 52,
-    SBK_QT3DANIMATION_QKEYFRAMEANIMATION_REPEATMODE_IDX      = 58,
-    SBK_QT3DANIMATION_QKEYFRAMEANIMATION_IDX                 = 56,
-    SBK_QT3DANIMATION_QLERPCLIPBLEND_IDX                     = 60,
-    SBK_QT3DANIMATION_QMORPHTARGET_IDX                       = 62,
-    SBK_QT3DANIMATION_QMORPHINGANIMATION_METHOD_IDX          = 66,
-    SBK_QT3DANIMATION_QMORPHINGANIMATION_IDX                 = 64,
-    SBK_QT3DANIMATION_QSKELETONMAPPING_IDX                   = 68,
-    SBK_QT3DANIMATION_QVERTEXBLENDANIMATION_IDX              = 70,
-    SBK_QT3DANIMATION_IDX_COUNT                              = 72,
+    SBK_QT3DANIMATION_QCALLBACKMAPPING_IDX                   = 38,
+    SBK_QT3DANIMATION_QCHANNEL_IDX                           = 40,
+    SBK_QT3DANIMATION_QCHANNELCOMPONENT_IDX                  = 42,
+    SBK_QT3DANIMATION_QCHANNELMAPPER_IDX                     = 44,
+    SBK_QT3DANIMATION_QCHANNELMAPPING_IDX                    = 46,
+    SBK_QT3DANIMATION_QCLIPANIMATOR_IDX                      = 48,
+    SBK_QT3DANIMATION_QCLIPBLENDVALUE_IDX                    = 50,
+    SBK_QT3DANIMATION_QCLOCK_IDX                             = 52,
+    SBK_QT3DANIMATION_QKEYFRAME_INTERPOLATIONTYPE_IDX        = 56,
+    SBK_QT3DANIMATION_QKEYFRAME_IDX                          = 54,
+    SBK_QT3DANIMATION_QKEYFRAMEANIMATION_REPEATMODE_IDX      = 60,
+    SBK_QT3DANIMATION_QKEYFRAMEANIMATION_IDX                 = 58,
+    SBK_QT3DANIMATION_QLERPCLIPBLEND_IDX                     = 62,
+    SBK_QT3DANIMATION_QMORPHTARGET_IDX                       = 64,
+    SBK_QT3DANIMATION_QMORPHINGANIMATION_METHOD_IDX          = 68,
+    SBK_QT3DANIMATION_QMORPHINGANIMATION_IDX                 = 66,
+    SBK_QT3DANIMATION_QSKELETONMAPPING_IDX                   = 70,
+    SBK_QT3DANIMATION_QVERTEXBLENDANIMATION_IDX              = 72,
+    SBK_QT3DANIMATION_IDX_COUNT                              = 74,
 };
 
 // Type indices
@@ -113,24 +118,25 @@ enum : int {
     SBK_Qt3DAnimation_QAnimationController_IDX               = 16,
     SBK_Qt3DAnimation_QAnimationGroup_IDX                    = 17,
     SBK_Qt3DAnimation_QBlendedClipAnimator_IDX               = 18,
-    SBK_Qt3DAnimation_QChannel_IDX                           = 19,
-    SBK_Qt3DAnimation_QChannelComponent_IDX                  = 20,
-    SBK_Qt3DAnimation_QChannelMapper_IDX                     = 21,
-    SBK_Qt3DAnimation_QChannelMapping_IDX                    = 22,
-    SBK_Qt3DAnimation_QClipAnimator_IDX                      = 23,
-    SBK_Qt3DAnimation_QClipBlendValue_IDX                    = 24,
-    SBK_Qt3DAnimation_QClock_IDX                             = 25,
-    SBK_Qt3DAnimation_QKeyFrame_InterpolationType_IDX        = 27,
-    SBK_Qt3DAnimation_QKeyFrame_IDX                          = 26,
-    SBK_Qt3DAnimation_QKeyframeAnimation_RepeatMode_IDX      = 29,
-    SBK_Qt3DAnimation_QKeyframeAnimation_IDX                 = 28,
-    SBK_Qt3DAnimation_QLerpClipBlend_IDX                     = 30,
-    SBK_Qt3DAnimation_QMorphTarget_IDX                       = 31,
-    SBK_Qt3DAnimation_QMorphingAnimation_Method_IDX          = 33,
-    SBK_Qt3DAnimation_QMorphingAnimation_IDX                 = 32,
-    SBK_Qt3DAnimation_QSkeletonMapping_IDX                   = 34,
-    SBK_Qt3DAnimation_QVertexBlendAnimation_IDX              = 35,
-    SBK_Qt3DAnimation_IDX_COUNT                              = 36,
+    SBK_Qt3DAnimation_QCallbackMapping_IDX                   = 19,
+    SBK_Qt3DAnimation_QChannel_IDX                           = 20,
+    SBK_Qt3DAnimation_QChannelComponent_IDX                  = 21,
+    SBK_Qt3DAnimation_QChannelMapper_IDX                     = 22,
+    SBK_Qt3DAnimation_QChannelMapping_IDX                    = 23,
+    SBK_Qt3DAnimation_QClipAnimator_IDX                      = 24,
+    SBK_Qt3DAnimation_QClipBlendValue_IDX                    = 25,
+    SBK_Qt3DAnimation_QClock_IDX                             = 26,
+    SBK_Qt3DAnimation_QKeyFrame_InterpolationType_IDX        = 28,
+    SBK_Qt3DAnimation_QKeyFrame_IDX                          = 27,
+    SBK_Qt3DAnimation_QKeyframeAnimation_RepeatMode_IDX      = 30,
+    SBK_Qt3DAnimation_QKeyframeAnimation_IDX                 = 29,
+    SBK_Qt3DAnimation_QLerpClipBlend_IDX                     = 31,
+    SBK_Qt3DAnimation_QMorphTarget_IDX                       = 32,
+    SBK_Qt3DAnimation_QMorphingAnimation_Method_IDX          = 34,
+    SBK_Qt3DAnimation_QMorphingAnimation_IDX                 = 33,
+    SBK_Qt3DAnimation_QSkeletonMapping_IDX                   = 35,
+    SBK_Qt3DAnimation_QVertexBlendAnimation_IDX              = 36,
+    SBK_Qt3DAnimation_IDX_COUNT                              = 37,
 };
 
 // This variable stores all Python types exported by this module.
@@ -209,6 +215,7 @@ template<> inline PyTypeObject *SbkType< ::Qt3DAnimation::QAnimationClipLoader >
 template<> inline PyTypeObject *SbkType< ::Qt3DAnimation::QAnimationController >() { return Shiboken::Module::get(SbkPySide6_Qt3DAnimationTypeStructs[SBK_Qt3DAnimation_QAnimationController_IDX]); }
 template<> inline PyTypeObject *SbkType< ::Qt3DAnimation::QAnimationGroup >() { return Shiboken::Module::get(SbkPySide6_Qt3DAnimationTypeStructs[SBK_Qt3DAnimation_QAnimationGroup_IDX]); }
 template<> inline PyTypeObject *SbkType< ::Qt3DAnimation::QBlendedClipAnimator >() { return Shiboken::Module::get(SbkPySide6_Qt3DAnimationTypeStructs[SBK_Qt3DAnimation_QBlendedClipAnimator_IDX]); }
+template<> inline PyTypeObject *SbkType< ::Qt3DAnimation::QCallbackMapping >() { return Shiboken::Module::get(SbkPySide6_Qt3DAnimationTypeStructs[SBK_Qt3DAnimation_QCallbackMapping_IDX]); }
 template<> inline PyTypeObject *SbkType< ::Qt3DAnimation::QChannel >() { return Shiboken::Module::get(SbkPySide6_Qt3DAnimationTypeStructs[SBK_Qt3DAnimation_QChannel_IDX]); }
 template<> inline PyTypeObject *SbkType< ::Qt3DAnimation::QChannelComponent >() { return Shiboken::Module::get(SbkPySide6_Qt3DAnimationTypeStructs[SBK_Qt3DAnimation_QChannelComponent_IDX]); }
 template<> inline PyTypeObject *SbkType< ::Qt3DAnimation::QChannelMapper >() { return Shiboken::Module::get(SbkPySide6_Qt3DAnimationTypeStructs[SBK_Qt3DAnimation_QChannelMapper_IDX]); }
