@@ -21,6 +21,8 @@
 // Bound library includes
 #include <Qt3DExtras/qabstractcameracontroller.h>
 
+QT_BEGIN_NAMESPACE
+
 namespace Qt3DExtras {
     class QAbstractSpriteSheet;
     class QConeGeometry;
@@ -66,6 +68,7 @@ namespace Qt3DExtras {
     class QTorusMesh;
     class Qt3DWindow;
 }
+QT_END_NAMESPACE
 
 // Type indices
 enum [[deprecated]] : int {
