@@ -47,6 +47,8 @@
 #ifndef QT_NO_NETWORKINTERFACE
 #include <QtNetwork/qnetworkinterface.h>
 #endif
+
+QT_BEGIN_NAMESPACE
 class QAbstractNetworkCache;
 class QAuthenticator;
 class QDnsDomainNameRecord;
@@ -54,7 +56,7 @@ class QDnsHostAddressRecord;
 class QDnsMailExchangeRecord;
 class QDnsServiceRecord;
 class QDnsTextRecord;
-class QDtlsClientVerifier;
+class QHttp1Configuration;
 class QHttp2Configuration;
 class QHttpPart;
 class QIPv6Address;
@@ -76,6 +78,7 @@ class QSslServer;
 class QTcpServer;
 class QTcpSocket;
 class QUdpSocket;
+QT_END_NAMESPACE
 
 // Type indices
 enum [[deprecated]] : int {
@@ -86,9 +89,9 @@ enum [[deprecated]] : int {
     SBK_QABSTRACTSOCKET_SOCKETSTATE_IDX                      = 14,
     SBK_QABSTRACTSOCKET_SOCKETOPTION_IDX                     = 12,
     SBK_QABSTRACTSOCKET_BINDFLAG_IDX                         = 4,
-    SBK_QFLAGS_QABSTRACTSOCKET_BINDFLAG_IDX                  = 44,
+    SBK_QFLAGS_QABSTRACTSOCKET_BINDFLAG_IDX                  = 46,
     SBK_QABSTRACTSOCKET_PAUSEMODE_IDX                        = 8,
-    SBK_QFLAGS_QABSTRACTSOCKET_PAUSEMODE_IDX                 = 46,
+    SBK_QFLAGS_QABSTRACTSOCKET_PAUSEMODE_IDX                 = 48,
     SBK_QABSTRACTSOCKET_IDX                                  = 2,
     SBK_QAUTHENTICATOR_IDX                                   = 18,
     SBK_QDNSDOMAINNAMERECORD_IDX                             = 20,
@@ -102,109 +105,111 @@ enum [[deprecated]] : int {
     SBK_QDTLS_HANDSHAKESTATE_IDX                             = 38,
     SBK_QDTLS_IDX                                            = 36,
     SBK_QDTLSCLIENTVERIFIER_IDX                              = 40,
-    SBK_QHOSTADDRESS_SPECIALADDRESS_IDX                      = 68,
-    SBK_QHOSTADDRESS_CONVERSIONMODEFLAG_IDX                  = 66,
-    SBK_QFLAGS_QHOSTADDRESS_CONVERSIONMODEFLAG_IDX           = 48,
-    SBK_QHOSTADDRESS_IDX                                     = 64,
-    SBK_QHOSTINFO_HOSTINFOERROR_IDX                          = 72,
-    SBK_QHOSTINFO_IDX                                        = 70,
-    SBK_QHSTSPOLICY_POLICYFLAG_IDX                           = 76,
-    SBK_QFLAGS_QHSTSPOLICY_POLICYFLAG_IDX                    = 50,
-    SBK_QHSTSPOLICY_IDX                                      = 74,
-    SBK_QHTTP2CONFIGURATION_IDX                              = 78,
-    SBK_QHTTPHEADERS_WELLKNOWNHEADER_IDX                     = 82,
-    SBK_QHTTPHEADERS_IDX                                     = 80,
-    SBK_QHTTPMULTIPART_CONTENTTYPE_IDX                       = 86,
-    SBK_QHTTPMULTIPART_IDX                                   = 84,
-    SBK_QHTTPPART_IDX                                        = 88,
-    SBK_QIPV6ADDRESS_IDX                                     = 90,
-    SBK_QLOCALSERVER_SOCKETOPTION_IDX                        = 94,
-    SBK_QFLAGS_QLOCALSERVER_SOCKETOPTION_IDX                 = 52,
-    SBK_QLOCALSERVER_IDX                                     = 92,
-    SBK_QLOCALSOCKET_LOCALSOCKETERROR_IDX                    = 98,
-    SBK_QLOCALSOCKET_LOCALSOCKETSTATE_IDX                    = 100,
-    SBK_QLOCALSOCKET_SOCKETOPTION_IDX                        = 102,
-    SBK_QFLAGS_QLOCALSOCKET_SOCKETOPTION_IDX                 = 54,
-    SBK_QLOCALSOCKET_IDX                                     = 96,
-    SBK_QNETWORKACCESSMANAGER_OPERATION_IDX                  = 106,
-    SBK_QNETWORKACCESSMANAGER_IDX                            = 104,
-    SBK_QNETWORKADDRESSENTRY_DNSELIGIBILITYSTATUS_IDX        = 110,
-    SBK_QNETWORKADDRESSENTRY_IDX                             = 108,
-    SBK_QNETWORKCACHEMETADATA_IDX                            = 112,
-    SBK_QNETWORKCOOKIE_RAWFORM_IDX                           = 116,
-    SBK_QNETWORKCOOKIE_SAMESITE_IDX                          = 118,
-    SBK_QNETWORKCOOKIE_IDX                                   = 114,
-    SBK_QNETWORKCOOKIEJAR_IDX                                = 120,
-    SBK_QNETWORKDATAGRAM_IDX                                 = 122,
-    SBK_QNETWORKDISKCACHE_IDX                                = 124,
-    SBK_QNETWORKINFORMATION_REACHABILITY_IDX                 = 130,
-    SBK_QNETWORKINFORMATION_TRANSPORTMEDIUM_IDX              = 132,
-    SBK_QNETWORKINFORMATION_FEATURE_IDX                      = 128,
-    SBK_QFLAGS_QNETWORKINFORMATION_FEATURE_IDX               = 56,
-    SBK_QNETWORKINFORMATION_IDX                              = 126,
-    SBK_QNETWORKINTERFACE_INTERFACEFLAG_IDX                  = 136,
-    SBK_QFLAGS_QNETWORKINTERFACE_INTERFACEFLAG_IDX           = 58,
-    SBK_QNETWORKINTERFACE_INTERFACETYPE_IDX                  = 138,
-    SBK_QNETWORKINTERFACE_IDX                                = 134,
-    SBK_QNETWORKPROXY_PROXYTYPE_IDX                          = 144,
-    SBK_QNETWORKPROXY_CAPABILITY_IDX                         = 142,
-    SBK_QFLAGS_QNETWORKPROXY_CAPABILITY_IDX                  = 60,
-    SBK_QNETWORKPROXY_IDX                                    = 140,
-    SBK_QNETWORKPROXYFACTORY_IDX                             = 146,
-    SBK_QNETWORKPROXYQUERY_QUERYTYPE_IDX                     = 150,
-    SBK_QNETWORKPROXYQUERY_IDX                               = 148,
-    SBK_QNETWORKREPLY_NETWORKERROR_IDX                       = 154,
-    SBK_QNETWORKREPLY_IDX                                    = 152,
-    SBK_QNETWORKREQUEST_KNOWNHEADERS_IDX                     = 162,
-    SBK_QNETWORKREQUEST_ATTRIBUTE_IDX                        = 158,
-    SBK_QNETWORKREQUEST_CACHELOADCONTROL_IDX                 = 160,
-    SBK_QNETWORKREQUEST_LOADCONTROL_IDX                      = 164,
-    SBK_QNETWORKREQUEST_PRIORITY_IDX                         = 166,
-    SBK_QNETWORKREQUEST_REDIRECTPOLICY_IDX                   = 168,
-    SBK_QNETWORKREQUEST_TRANSFERTIMEOUTCONSTANT_IDX          = 170,
-    SBK_QNETWORKREQUEST_IDX                                  = 156,
-    SBK_QNETWORKREQUESTFACTORY_IDX                           = 172,
-    SBK_QOCSPRESPONSE_IDX                                    = 176,
-    SBK_QTNETWORKQPASSWORDDIGESTOR_IDX                       = 180,
-    SBK_QRESTACCESSMANAGER_IDX                               = 182,
-    SBK_QRESTREPLY_IDX                                       = 184,
-    SBK_QSSL_KEYTYPE_IDX                                     = 200,
-    SBK_QSSL_ENCODINGFORMAT_IDX                              = 194,
-    SBK_QSSL_KEYALGORITHM_IDX                                = 198,
-    SBK_QSSL_ALTERNATIVENAMEENTRYTYPE_IDX                    = 192,
-    SBK_QSSL_SSLPROTOCOL_IDX                                 = 204,
-    SBK_QSSL_SSLOPTION_IDX                                   = 202,
-    SBK_QFLAGS_QSSL_SSLOPTION_IDX                            = 62,
-    SBK_QSSL_ALERTLEVEL_IDX                                  = 188,
-    SBK_QSSL_ALERTTYPE_IDX                                   = 190,
-    SBK_QSSL_IMPLEMENTEDCLASS_IDX                            = 196,
-    SBK_QSSL_SUPPORTEDFEATURE_IDX                            = 206,
-    SBK_QTNETWORKQSSL_IDX                                    = 186,
-    SBK_QSSLCERTIFICATE_SUBJECTINFO_IDX                      = 212,
-    SBK_QSSLCERTIFICATE_PATTERNSYNTAX_IDX                    = 210,
-    SBK_QSSLCERTIFICATE_IDX                                  = 208,
-    SBK_QSSLCERTIFICATEEXTENSION_IDX                         = 214,
-    SBK_QSSLCIPHER_IDX                                       = 216,
-    SBK_QSSLCONFIGURATION_NEXTPROTOCOLNEGOTIATIONSTATUS_IDX  = 220,
-    SBK_QSSLCONFIGURATION_IDX                                = 218,
-    SBK_QSSLDIFFIEHELLMANPARAMETERS_ERROR_IDX                = 224,
-    SBK_QSSLDIFFIEHELLMANPARAMETERS_IDX                      = 222,
-    SBK_QSSLELLIPTICCURVE_IDX                                = 226,
-    SBK_QSSLERROR_SSLERROR_IDX                               = 230,
-    SBK_QSSLERROR_IDX                                        = 228,
-    SBK_QSSLKEY_IDX                                          = 232,
-    SBK_QSSLPRESHAREDKEYAUTHENTICATOR_IDX                    = 234,
-    SBK_QSSLSERVER_IDX                                       = 236,
-    SBK_QSSLSOCKET_SSLMODE_IDX                               = 242,
-    SBK_QSSLSOCKET_PEERVERIFYMODE_IDX                        = 240,
-    SBK_QSSLSOCKET_IDX                                       = 238,
-    SBK_QTCPSERVER_IDX                                       = 244,
-    SBK_QTCPSOCKET_IDX                                       = 246,
-    SBK_QUDPSOCKET_IDX                                       = 248,
-    SBK_QDTLSERROR_IDX                                       = 42,
-    SBK_QOCSPCERTIFICATESTATUS_IDX                           = 174,
-    SBK_QOCSPREVOCATIONREASON_IDX                            = 178,
-    SBK_QTNETWORK_IDX_COUNT                                  = 250,
+    SBK_QDTLSCLIENTVERIFIER_GENERATORPARAMETERS_IDX          = 42,
+    SBK_QHOSTADDRESS_SPECIALADDRESS_IDX                      = 70,
+    SBK_QHOSTADDRESS_CONVERSIONMODEFLAG_IDX                  = 68,
+    SBK_QFLAGS_QHOSTADDRESS_CONVERSIONMODEFLAG_IDX           = 50,
+    SBK_QHOSTADDRESS_IDX                                     = 66,
+    SBK_QHOSTINFO_HOSTINFOERROR_IDX                          = 74,
+    SBK_QHOSTINFO_IDX                                        = 72,
+    SBK_QHSTSPOLICY_POLICYFLAG_IDX                           = 78,
+    SBK_QFLAGS_QHSTSPOLICY_POLICYFLAG_IDX                    = 52,
+    SBK_QHSTSPOLICY_IDX                                      = 76,
+    SBK_QHTTP1CONFIGURATION_IDX                              = 80,
+    SBK_QHTTP2CONFIGURATION_IDX                              = 82,
+    SBK_QHTTPHEADERS_WELLKNOWNHEADER_IDX                     = 86,
+    SBK_QHTTPHEADERS_IDX                                     = 84,
+    SBK_QHTTPMULTIPART_CONTENTTYPE_IDX                       = 90,
+    SBK_QHTTPMULTIPART_IDX                                   = 88,
+    SBK_QHTTPPART_IDX                                        = 92,
+    SBK_QIPV6ADDRESS_IDX                                     = 94,
+    SBK_QLOCALSERVER_SOCKETOPTION_IDX                        = 98,
+    SBK_QFLAGS_QLOCALSERVER_SOCKETOPTION_IDX                 = 54,
+    SBK_QLOCALSERVER_IDX                                     = 96,
+    SBK_QLOCALSOCKET_LOCALSOCKETERROR_IDX                    = 102,
+    SBK_QLOCALSOCKET_LOCALSOCKETSTATE_IDX                    = 104,
+    SBK_QLOCALSOCKET_SOCKETOPTION_IDX                        = 106,
+    SBK_QFLAGS_QLOCALSOCKET_SOCKETOPTION_IDX                 = 56,
+    SBK_QLOCALSOCKET_IDX                                     = 100,
+    SBK_QNETWORKACCESSMANAGER_OPERATION_IDX                  = 110,
+    SBK_QNETWORKACCESSMANAGER_IDX                            = 108,
+    SBK_QNETWORKADDRESSENTRY_DNSELIGIBILITYSTATUS_IDX        = 114,
+    SBK_QNETWORKADDRESSENTRY_IDX                             = 112,
+    SBK_QNETWORKCACHEMETADATA_IDX                            = 116,
+    SBK_QNETWORKCOOKIE_RAWFORM_IDX                           = 120,
+    SBK_QNETWORKCOOKIE_SAMESITE_IDX                          = 122,
+    SBK_QNETWORKCOOKIE_IDX                                   = 118,
+    SBK_QNETWORKCOOKIEJAR_IDX                                = 124,
+    SBK_QNETWORKDATAGRAM_IDX                                 = 126,
+    SBK_QNETWORKDISKCACHE_IDX                                = 128,
+    SBK_QNETWORKINFORMATION_REACHABILITY_IDX                 = 134,
+    SBK_QNETWORKINFORMATION_TRANSPORTMEDIUM_IDX              = 136,
+    SBK_QNETWORKINFORMATION_FEATURE_IDX                      = 132,
+    SBK_QFLAGS_QNETWORKINFORMATION_FEATURE_IDX               = 58,
+    SBK_QNETWORKINFORMATION_IDX                              = 130,
+    SBK_QNETWORKINTERFACE_INTERFACEFLAG_IDX                  = 140,
+    SBK_QFLAGS_QNETWORKINTERFACE_INTERFACEFLAG_IDX           = 60,
+    SBK_QNETWORKINTERFACE_INTERFACETYPE_IDX                  = 142,
+    SBK_QNETWORKINTERFACE_IDX                                = 138,
+    SBK_QNETWORKPROXY_PROXYTYPE_IDX                          = 148,
+    SBK_QNETWORKPROXY_CAPABILITY_IDX                         = 146,
+    SBK_QFLAGS_QNETWORKPROXY_CAPABILITY_IDX                  = 62,
+    SBK_QNETWORKPROXY_IDX                                    = 144,
+    SBK_QNETWORKPROXYFACTORY_IDX                             = 150,
+    SBK_QNETWORKPROXYQUERY_QUERYTYPE_IDX                     = 154,
+    SBK_QNETWORKPROXYQUERY_IDX                               = 152,
+    SBK_QNETWORKREPLY_NETWORKERROR_IDX                       = 158,
+    SBK_QNETWORKREPLY_IDX                                    = 156,
+    SBK_QNETWORKREQUEST_KNOWNHEADERS_IDX                     = 166,
+    SBK_QNETWORKREQUEST_ATTRIBUTE_IDX                        = 162,
+    SBK_QNETWORKREQUEST_CACHELOADCONTROL_IDX                 = 164,
+    SBK_QNETWORKREQUEST_LOADCONTROL_IDX                      = 168,
+    SBK_QNETWORKREQUEST_PRIORITY_IDX                         = 170,
+    SBK_QNETWORKREQUEST_REDIRECTPOLICY_IDX                   = 172,
+    SBK_QNETWORKREQUEST_TRANSFERTIMEOUTCONSTANT_IDX          = 174,
+    SBK_QNETWORKREQUEST_IDX                                  = 160,
+    SBK_QNETWORKREQUESTFACTORY_IDX                           = 176,
+    SBK_QOCSPRESPONSE_IDX                                    = 180,
+    SBK_QTNETWORKQPASSWORDDIGESTOR_IDX                       = 184,
+    SBK_QRESTACCESSMANAGER_IDX                               = 186,
+    SBK_QRESTREPLY_IDX                                       = 188,
+    SBK_QSSL_KEYTYPE_IDX                                     = 204,
+    SBK_QSSL_ENCODINGFORMAT_IDX                              = 198,
+    SBK_QSSL_KEYALGORITHM_IDX                                = 202,
+    SBK_QSSL_ALTERNATIVENAMEENTRYTYPE_IDX                    = 196,
+    SBK_QSSL_SSLPROTOCOL_IDX                                 = 208,
+    SBK_QSSL_SSLOPTION_IDX                                   = 206,
+    SBK_QFLAGS_QSSL_SSLOPTION_IDX                            = 64,
+    SBK_QSSL_ALERTLEVEL_IDX                                  = 192,
+    SBK_QSSL_ALERTTYPE_IDX                                   = 194,
+    SBK_QSSL_IMPLEMENTEDCLASS_IDX                            = 200,
+    SBK_QSSL_SUPPORTEDFEATURE_IDX                            = 210,
+    SBK_QTNETWORKQSSL_IDX                                    = 190,
+    SBK_QSSLCERTIFICATE_SUBJECTINFO_IDX                      = 216,
+    SBK_QSSLCERTIFICATE_PATTERNSYNTAX_IDX                    = 214,
+    SBK_QSSLCERTIFICATE_IDX                                  = 212,
+    SBK_QSSLCERTIFICATEEXTENSION_IDX                         = 218,
+    SBK_QSSLCIPHER_IDX                                       = 220,
+    SBK_QSSLCONFIGURATION_NEXTPROTOCOLNEGOTIATIONSTATUS_IDX  = 224,
+    SBK_QSSLCONFIGURATION_IDX                                = 222,
+    SBK_QSSLDIFFIEHELLMANPARAMETERS_ERROR_IDX                = 228,
+    SBK_QSSLDIFFIEHELLMANPARAMETERS_IDX                      = 226,
+    SBK_QSSLELLIPTICCURVE_IDX                                = 230,
+    SBK_QSSLERROR_SSLERROR_IDX                               = 234,
+    SBK_QSSLERROR_IDX                                        = 232,
+    SBK_QSSLKEY_IDX                                          = 236,
+    SBK_QSSLPRESHAREDKEYAUTHENTICATOR_IDX                    = 238,
+    SBK_QSSLSERVER_IDX                                       = 240,
+    SBK_QSSLSOCKET_SSLMODE_IDX                               = 246,
+    SBK_QSSLSOCKET_PEERVERIFYMODE_IDX                        = 244,
+    SBK_QSSLSOCKET_IDX                                       = 242,
+    SBK_QTCPSERVER_IDX                                       = 248,
+    SBK_QTCPSOCKET_IDX                                       = 250,
+    SBK_QUDPSOCKET_IDX                                       = 252,
+    SBK_QDTLSERROR_IDX                                       = 44,
+    SBK_QOCSPCERTIFICATESTATUS_IDX                           = 178,
+    SBK_QOCSPREVOCATIONREASON_IDX                            = 182,
+    SBK_QTNETWORK_IDX_COUNT                                  = 254,
 };
 
 // Type indices
@@ -216,9 +221,9 @@ enum : int {
     SBK_QAbstractSocket_SocketState_IDX                      = 7,
     SBK_QAbstractSocket_SocketOption_IDX                     = 6,
     SBK_QAbstractSocket_BindFlag_IDX                         = 2,
-    SBK_QFlags_QAbstractSocket_BindFlag_IDX                  = 22,
+    SBK_QFlags_QAbstractSocket_BindFlag_IDX                  = 23,
     SBK_QAbstractSocket_PauseMode_IDX                        = 4,
-    SBK_QFlags_QAbstractSocket_PauseMode_IDX                 = 23,
+    SBK_QFlags_QAbstractSocket_PauseMode_IDX                 = 24,
     SBK_QAbstractSocket_IDX                                  = 1,
     SBK_QAuthenticator_IDX                                   = 9,
     SBK_QDnsDomainNameRecord_IDX                             = 10,
@@ -232,109 +237,111 @@ enum : int {
     SBK_QDtls_HandshakeState_IDX                             = 19,
     SBK_QDtls_IDX                                            = 18,
     SBK_QDtlsClientVerifier_IDX                              = 20,
-    SBK_QHostAddress_SpecialAddress_IDX                      = 34,
-    SBK_QHostAddress_ConversionModeFlag_IDX                  = 33,
-    SBK_QFlags_QHostAddress_ConversionModeFlag_IDX           = 24,
-    SBK_QHostAddress_IDX                                     = 32,
-    SBK_QHostInfo_HostInfoError_IDX                          = 36,
-    SBK_QHostInfo_IDX                                        = 35,
-    SBK_QHstsPolicy_PolicyFlag_IDX                           = 38,
-    SBK_QFlags_QHstsPolicy_PolicyFlag_IDX                    = 25,
-    SBK_QHstsPolicy_IDX                                      = 37,
-    SBK_QHttp2Configuration_IDX                              = 39,
-    SBK_QHttpHeaders_WellKnownHeader_IDX                     = 41,
-    SBK_QHttpHeaders_IDX                                     = 40,
-    SBK_QHttpMultiPart_ContentType_IDX                       = 43,
-    SBK_QHttpMultiPart_IDX                                   = 42,
-    SBK_QHttpPart_IDX                                        = 44,
-    SBK_QIPv6Address_IDX                                     = 45,
-    SBK_QLocalServer_SocketOption_IDX                        = 47,
-    SBK_QFlags_QLocalServer_SocketOption_IDX                 = 26,
-    SBK_QLocalServer_IDX                                     = 46,
-    SBK_QLocalSocket_LocalSocketError_IDX                    = 49,
-    SBK_QLocalSocket_LocalSocketState_IDX                    = 50,
-    SBK_QLocalSocket_SocketOption_IDX                        = 51,
-    SBK_QFlags_QLocalSocket_SocketOption_IDX                 = 27,
-    SBK_QLocalSocket_IDX                                     = 48,
-    SBK_QNetworkAccessManager_Operation_IDX                  = 53,
-    SBK_QNetworkAccessManager_IDX                            = 52,
-    SBK_QNetworkAddressEntry_DnsEligibilityStatus_IDX        = 55,
-    SBK_QNetworkAddressEntry_IDX                             = 54,
-    SBK_QNetworkCacheMetaData_IDX                            = 56,
-    SBK_QNetworkCookie_RawForm_IDX                           = 58,
-    SBK_QNetworkCookie_SameSite_IDX                          = 59,
-    SBK_QNetworkCookie_IDX                                   = 57,
-    SBK_QNetworkCookieJar_IDX                                = 60,
-    SBK_QNetworkDatagram_IDX                                 = 61,
-    SBK_QNetworkDiskCache_IDX                                = 62,
-    SBK_QNetworkInformation_Reachability_IDX                 = 65,
-    SBK_QNetworkInformation_TransportMedium_IDX              = 66,
-    SBK_QNetworkInformation_Feature_IDX                      = 64,
-    SBK_QFlags_QNetworkInformation_Feature_IDX               = 28,
-    SBK_QNetworkInformation_IDX                              = 63,
-    SBK_QNetworkInterface_InterfaceFlag_IDX                  = 68,
-    SBK_QFlags_QNetworkInterface_InterfaceFlag_IDX           = 29,
-    SBK_QNetworkInterface_InterfaceType_IDX                  = 69,
-    SBK_QNetworkInterface_IDX                                = 67,
-    SBK_QNetworkProxy_ProxyType_IDX                          = 72,
-    SBK_QNetworkProxy_Capability_IDX                         = 71,
-    SBK_QFlags_QNetworkProxy_Capability_IDX                  = 30,
-    SBK_QNetworkProxy_IDX                                    = 70,
-    SBK_QNetworkProxyFactory_IDX                             = 73,
-    SBK_QNetworkProxyQuery_QueryType_IDX                     = 75,
-    SBK_QNetworkProxyQuery_IDX                               = 74,
-    SBK_QNetworkReply_NetworkError_IDX                       = 77,
-    SBK_QNetworkReply_IDX                                    = 76,
-    SBK_QNetworkRequest_KnownHeaders_IDX                     = 81,
-    SBK_QNetworkRequest_Attribute_IDX                        = 79,
-    SBK_QNetworkRequest_CacheLoadControl_IDX                 = 80,
-    SBK_QNetworkRequest_LoadControl_IDX                      = 82,
-    SBK_QNetworkRequest_Priority_IDX                         = 83,
-    SBK_QNetworkRequest_RedirectPolicy_IDX                   = 84,
-    SBK_QNetworkRequest_TransferTimeoutConstant_IDX          = 85,
-    SBK_QNetworkRequest_IDX                                  = 78,
-    SBK_QNetworkRequestFactory_IDX                           = 86,
-    SBK_QOcspResponse_IDX                                    = 88,
-    SBK_QtNetworkQPasswordDigestor_IDX                       = 90,
-    SBK_QRestAccessManager_IDX                               = 91,
-    SBK_QRestReply_IDX                                       = 92,
-    SBK_QSsl_KeyType_IDX                                     = 100,
-    SBK_QSsl_EncodingFormat_IDX                              = 97,
-    SBK_QSsl_KeyAlgorithm_IDX                                = 99,
-    SBK_QSsl_AlternativeNameEntryType_IDX                    = 96,
-    SBK_QSsl_SslProtocol_IDX                                 = 102,
-    SBK_QSsl_SslOption_IDX                                   = 101,
-    SBK_QFlags_QSsl_SslOption_IDX                            = 31,
-    SBK_QSsl_AlertLevel_IDX                                  = 94,
-    SBK_QSsl_AlertType_IDX                                   = 95,
-    SBK_QSsl_ImplementedClass_IDX                            = 98,
-    SBK_QSsl_SupportedFeature_IDX                            = 103,
-    SBK_QtNetworkQSsl_IDX                                    = 93,
-    SBK_QSslCertificate_SubjectInfo_IDX                      = 106,
-    SBK_QSslCertificate_PatternSyntax_IDX                    = 105,
-    SBK_QSslCertificate_IDX                                  = 104,
-    SBK_QSslCertificateExtension_IDX                         = 107,
-    SBK_QSslCipher_IDX                                       = 108,
-    SBK_QSslConfiguration_NextProtocolNegotiationStatus_IDX  = 110,
-    SBK_QSslConfiguration_IDX                                = 109,
-    SBK_QSslDiffieHellmanParameters_Error_IDX                = 112,
-    SBK_QSslDiffieHellmanParameters_IDX                      = 111,
-    SBK_QSslEllipticCurve_IDX                                = 113,
-    SBK_QSslError_SslError_IDX                               = 115,
-    SBK_QSslError_IDX                                        = 114,
-    SBK_QSslKey_IDX                                          = 116,
-    SBK_QSslPreSharedKeyAuthenticator_IDX                    = 117,
-    SBK_QSslServer_IDX                                       = 118,
-    SBK_QSslSocket_SslMode_IDX                               = 121,
-    SBK_QSslSocket_PeerVerifyMode_IDX                        = 120,
-    SBK_QSslSocket_IDX                                       = 119,
-    SBK_QTcpServer_IDX                                       = 122,
-    SBK_QTcpSocket_IDX                                       = 123,
-    SBK_QUdpSocket_IDX                                       = 124,
-    SBK_QDtlsError_IDX                                       = 21,
-    SBK_QOcspCertificateStatus_IDX                           = 87,
-    SBK_QOcspRevocationReason_IDX                            = 89,
-    SBK_QtNetwork_IDX_COUNT                                  = 125,
+    SBK_QDtlsClientVerifier_GeneratorParameters_IDX          = 21,
+    SBK_QHostAddress_SpecialAddress_IDX                      = 35,
+    SBK_QHostAddress_ConversionModeFlag_IDX                  = 34,
+    SBK_QFlags_QHostAddress_ConversionModeFlag_IDX           = 25,
+    SBK_QHostAddress_IDX                                     = 33,
+    SBK_QHostInfo_HostInfoError_IDX                          = 37,
+    SBK_QHostInfo_IDX                                        = 36,
+    SBK_QHstsPolicy_PolicyFlag_IDX                           = 39,
+    SBK_QFlags_QHstsPolicy_PolicyFlag_IDX                    = 26,
+    SBK_QHstsPolicy_IDX                                      = 38,
+    SBK_QHttp1Configuration_IDX                              = 40,
+    SBK_QHttp2Configuration_IDX                              = 41,
+    SBK_QHttpHeaders_WellKnownHeader_IDX                     = 43,
+    SBK_QHttpHeaders_IDX                                     = 42,
+    SBK_QHttpMultiPart_ContentType_IDX                       = 45,
+    SBK_QHttpMultiPart_IDX                                   = 44,
+    SBK_QHttpPart_IDX                                        = 46,
+    SBK_QIPv6Address_IDX                                     = 47,
+    SBK_QLocalServer_SocketOption_IDX                        = 49,
+    SBK_QFlags_QLocalServer_SocketOption_IDX                 = 27,
+    SBK_QLocalServer_IDX                                     = 48,
+    SBK_QLocalSocket_LocalSocketError_IDX                    = 51,
+    SBK_QLocalSocket_LocalSocketState_IDX                    = 52,
+    SBK_QLocalSocket_SocketOption_IDX                        = 53,
+    SBK_QFlags_QLocalSocket_SocketOption_IDX                 = 28,
+    SBK_QLocalSocket_IDX                                     = 50,
+    SBK_QNetworkAccessManager_Operation_IDX                  = 55,
+    SBK_QNetworkAccessManager_IDX                            = 54,
+    SBK_QNetworkAddressEntry_DnsEligibilityStatus_IDX        = 57,
+    SBK_QNetworkAddressEntry_IDX                             = 56,
+    SBK_QNetworkCacheMetaData_IDX                            = 58,
+    SBK_QNetworkCookie_RawForm_IDX                           = 60,
+    SBK_QNetworkCookie_SameSite_IDX                          = 61,
+    SBK_QNetworkCookie_IDX                                   = 59,
+    SBK_QNetworkCookieJar_IDX                                = 62,
+    SBK_QNetworkDatagram_IDX                                 = 63,
+    SBK_QNetworkDiskCache_IDX                                = 64,
+    SBK_QNetworkInformation_Reachability_IDX                 = 67,
+    SBK_QNetworkInformation_TransportMedium_IDX              = 68,
+    SBK_QNetworkInformation_Feature_IDX                      = 66,
+    SBK_QFlags_QNetworkInformation_Feature_IDX               = 29,
+    SBK_QNetworkInformation_IDX                              = 65,
+    SBK_QNetworkInterface_InterfaceFlag_IDX                  = 70,
+    SBK_QFlags_QNetworkInterface_InterfaceFlag_IDX           = 30,
+    SBK_QNetworkInterface_InterfaceType_IDX                  = 71,
+    SBK_QNetworkInterface_IDX                                = 69,
+    SBK_QNetworkProxy_ProxyType_IDX                          = 74,
+    SBK_QNetworkProxy_Capability_IDX                         = 73,
+    SBK_QFlags_QNetworkProxy_Capability_IDX                  = 31,
+    SBK_QNetworkProxy_IDX                                    = 72,
+    SBK_QNetworkProxyFactory_IDX                             = 75,
+    SBK_QNetworkProxyQuery_QueryType_IDX                     = 77,
+    SBK_QNetworkProxyQuery_IDX                               = 76,
+    SBK_QNetworkReply_NetworkError_IDX                       = 79,
+    SBK_QNetworkReply_IDX                                    = 78,
+    SBK_QNetworkRequest_KnownHeaders_IDX                     = 83,
+    SBK_QNetworkRequest_Attribute_IDX                        = 81,
+    SBK_QNetworkRequest_CacheLoadControl_IDX                 = 82,
+    SBK_QNetworkRequest_LoadControl_IDX                      = 84,
+    SBK_QNetworkRequest_Priority_IDX                         = 85,
+    SBK_QNetworkRequest_RedirectPolicy_IDX                   = 86,
+    SBK_QNetworkRequest_TransferTimeoutConstant_IDX          = 87,
+    SBK_QNetworkRequest_IDX                                  = 80,
+    SBK_QNetworkRequestFactory_IDX                           = 88,
+    SBK_QOcspResponse_IDX                                    = 90,
+    SBK_QtNetworkQPasswordDigestor_IDX                       = 92,
+    SBK_QRestAccessManager_IDX                               = 93,
+    SBK_QRestReply_IDX                                       = 94,
+    SBK_QSsl_KeyType_IDX                                     = 102,
+    SBK_QSsl_EncodingFormat_IDX                              = 99,
+    SBK_QSsl_KeyAlgorithm_IDX                                = 101,
+    SBK_QSsl_AlternativeNameEntryType_IDX                    = 98,
+    SBK_QSsl_SslProtocol_IDX                                 = 104,
+    SBK_QSsl_SslOption_IDX                                   = 103,
+    SBK_QFlags_QSsl_SslOption_IDX                            = 32,
+    SBK_QSsl_AlertLevel_IDX                                  = 96,
+    SBK_QSsl_AlertType_IDX                                   = 97,
+    SBK_QSsl_ImplementedClass_IDX                            = 100,
+    SBK_QSsl_SupportedFeature_IDX                            = 105,
+    SBK_QtNetworkQSsl_IDX                                    = 95,
+    SBK_QSslCertificate_SubjectInfo_IDX                      = 108,
+    SBK_QSslCertificate_PatternSyntax_IDX                    = 107,
+    SBK_QSslCertificate_IDX                                  = 106,
+    SBK_QSslCertificateExtension_IDX                         = 109,
+    SBK_QSslCipher_IDX                                       = 110,
+    SBK_QSslConfiguration_NextProtocolNegotiationStatus_IDX  = 112,
+    SBK_QSslConfiguration_IDX                                = 111,
+    SBK_QSslDiffieHellmanParameters_Error_IDX                = 114,
+    SBK_QSslDiffieHellmanParameters_IDX                      = 113,
+    SBK_QSslEllipticCurve_IDX                                = 115,
+    SBK_QSslError_SslError_IDX                               = 117,
+    SBK_QSslError_IDX                                        = 116,
+    SBK_QSslKey_IDX                                          = 118,
+    SBK_QSslPreSharedKeyAuthenticator_IDX                    = 119,
+    SBK_QSslServer_IDX                                       = 120,
+    SBK_QSslSocket_SslMode_IDX                               = 123,
+    SBK_QSslSocket_PeerVerifyMode_IDX                        = 122,
+    SBK_QSslSocket_IDX                                       = 121,
+    SBK_QTcpServer_IDX                                       = 124,
+    SBK_QTcpSocket_IDX                                       = 125,
+    SBK_QUdpSocket_IDX                                       = 126,
+    SBK_QDtlsError_IDX                                       = 22,
+    SBK_QOcspCertificateStatus_IDX                           = 89,
+    SBK_QOcspRevocationReason_IDX                            = 91,
+    SBK_QtNetwork_IDX_COUNT                                  = 127,
 };
 
 // This variable stores all Python types exported by this module.
@@ -469,6 +476,9 @@ template<> inline PyTypeObject *SbkType< ::QDtls >() { return Shiboken::Module::
 #if QT_CONFIG(dtls)
 template<> inline PyTypeObject *SbkType< ::QDtlsClientVerifier >() { return Shiboken::Module::get(SbkPySide6_QtNetworkTypeStructs[SBK_QDtlsClientVerifier_IDX]); }
 #endif
+#if QT_CONFIG(dtls)
+template<> inline PyTypeObject *SbkType< ::QDtlsClientVerifier::GeneratorParameters >() { return Shiboken::Module::get(SbkPySide6_QtNetworkTypeStructs[SBK_QDtlsClientVerifier_GeneratorParameters_IDX]); }
+#endif
 template<> inline PyTypeObject *SbkType< ::QHostAddress::SpecialAddress >() { return Shiboken::Module::get(SbkPySide6_QtNetworkTypeStructs[SBK_QHostAddress_SpecialAddress_IDX]); }
 template<> inline PyTypeObject *SbkType< ::QHostAddress::ConversionModeFlag >() { return Shiboken::Module::get(SbkPySide6_QtNetworkTypeStructs[SBK_QHostAddress_ConversionModeFlag_IDX]); }
 template<> inline PyTypeObject *SbkType< ::QFlags<QHostAddress::ConversionModeFlag> >() { return Shiboken::Module::get(SbkPySide6_QtNetworkTypeStructs[SBK_QFlags_QHostAddress_ConversionModeFlag_IDX]); }
@@ -478,6 +488,7 @@ template<> inline PyTypeObject *SbkType< ::QHostInfo >() { return Shiboken::Modu
 template<> inline PyTypeObject *SbkType< ::QHstsPolicy::PolicyFlag >() { return Shiboken::Module::get(SbkPySide6_QtNetworkTypeStructs[SBK_QHstsPolicy_PolicyFlag_IDX]); }
 template<> inline PyTypeObject *SbkType< ::QFlags<QHstsPolicy::PolicyFlag> >() { return Shiboken::Module::get(SbkPySide6_QtNetworkTypeStructs[SBK_QFlags_QHstsPolicy_PolicyFlag_IDX]); }
 template<> inline PyTypeObject *SbkType< ::QHstsPolicy >() { return Shiboken::Module::get(SbkPySide6_QtNetworkTypeStructs[SBK_QHstsPolicy_IDX]); }
+template<> inline PyTypeObject *SbkType< ::QHttp1Configuration >() { return Shiboken::Module::get(SbkPySide6_QtNetworkTypeStructs[SBK_QHttp1Configuration_IDX]); }
 template<> inline PyTypeObject *SbkType< ::QHttp2Configuration >() { return Shiboken::Module::get(SbkPySide6_QtNetworkTypeStructs[SBK_QHttp2Configuration_IDX]); }
 template<> inline PyTypeObject *SbkType< ::QHttpHeaders::WellKnownHeader >() { return Shiboken::Module::get(SbkPySide6_QtNetworkTypeStructs[SBK_QHttpHeaders_WellKnownHeader_IDX]); }
 template<> inline PyTypeObject *SbkType< ::QHttpHeaders >() { return Shiboken::Module::get(SbkPySide6_QtNetworkTypeStructs[SBK_QHttpHeaders_IDX]); }
