@@ -20,6 +20,8 @@
 #include <QtSensors/qorientationsensor.h>
 #include <QtSensors/qsensor.h>
 #include <QtSensors/qtapsensor.h>
+
+QT_BEGIN_NAMESPACE
 class QAccelerometerFilter;
 class QAccelerometerReading;
 class QAmbientLightFilter;
@@ -72,6 +74,7 @@ class QTiltFilter;
 class QTiltReading;
 class QTiltSensor;
 struct qoutputrange;
+QT_END_NAMESPACE
 
 // Type indices
 enum [[deprecated]] : int {
