@@ -17,7 +17,10 @@
 // Bound library includes
 #include <QtTextToSpeech/qtexttospeech.h>
 #include <QtTextToSpeech/qvoice.h>
+
+QT_BEGIN_NAMESPACE
 class QTextToSpeechEngine;
+QT_END_NAMESPACE
 
 // Type indices
 enum [[deprecated]] : int {
