@@ -20,6 +20,9 @@
 #include <QtWebEngineQuick/qquickwebengineprofile.h>
 #include <QtWebEngineQuick/qtwebenginequickglobal.h>
 
+QT_BEGIN_NAMESPACE
+QT_END_NAMESPACE
+
 // Type indices
 enum [[deprecated]] : int {
     SBK_QQUICKWEBENGINEPROFILE_HTTPCACHETYPE_IDX             = 2,
