@@ -21,7 +21,10 @@
 #include <pyside6_qtwebchannel_python.h>
 
 // Bound library includes
+
+QT_BEGIN_NAMESPACE
 class QWebEngineView;
+QT_END_NAMESPACE
 
 // Type indices
 enum [[deprecated]] : int {
